@@ -15,7 +15,10 @@ size_t iconv_wrap(iconv_t cd,
                   size_t *outbytesleft)
 {
 	char *in = *inbuf;
+    /* Mac does not like the cast */
+#ifndef _DARWIN     /* RT 101294 */
 	const char *in_c = const_cast<const char*>(in);
+#endif /* _DARWIN  */
 	return iconv(cd, 
                  &in_c,
                  inbytesleft,
